==> dojo-1.9.4.tgz: package/cldr/nls/da/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "ugedag",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d/M/y",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"eraNarrow": [
		"f.Kr.",
		"e.Kr."
	],
	"dateFormatItem-yMM": "MM/y",
	"days-format-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"dateFormat-long": "d. MMM y",
	"months-format-wide": [
		"januar",
		"februar",
		"marts",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE 'den' d. MMMM y",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-wide-noon": "middag",
	"dateFormatItem-yMd": "d/M/y",
	"field-era": "æra",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"marts",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"september",
		"oktober",
		"november",
		"december"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "år",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "time",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mar.",
		"apr.",
		"maj",
		"jun.",
		"jul.",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgen",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "M",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dayPeriods-format-abbr-noon": "middag",
	"timeFormat-medium": "HH.mm.ss",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"f.Kr.",
		"e.Kr."
	],
	"field-minute": "minut",
	"field-dayperiod": "dagtid",
	"days-standAlone-abbr": [
		"søn",
		"man",
		"tir",
		"ons",
		"tor",
		"fre",
		"lør"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "i går",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-day": "dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "tidszone",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "sidste år",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"eraNames": [
		"f.Kr.",
		"e.Kr."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-MMM": "MMM",
	"field-month": "måned",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateFormat-short": "dd/MM/yy",
	"dayPeriods-format-narrow-noon": "middag",
	"field-second": "sekund",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"field-month-relative+0": "denne måned",
	"field-month-relative+1": "næste måned",
	"dateFormatItem-Ed": "E 'd'. d.",
	"field-week": "uge",
	"dateFormat-medium": "dd/MM/y",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "sidste uge",
	"field-year-relative+1": "næste år",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-week-relative+0": "denne uge",
	"field-week-relative+1": "næste uge"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/da/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h.mm a",
	"days-standAlone-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "nu",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Ugedag",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d/M/y",
	"field-wed-relative+0": "denne onsdag",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-wed-relative+1": "næste onsdag",
	"eraNarrow": [
		"fKr",
		"fvt",
		"eKr",
		"vt"
	],
	"dateFormatItem-yMM": "MM/y",
	"field-tue-relative+-1": "sidste tirsdag",
	"days-format-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"dateFormat-long": "d. MMMM y",
	"field-fri-relative+-1": "sidste fredag",
	"field-wed-relative+-1": "sidste onsdag",
	"months-format-wide": [
		"januar",
		"februar",
		"marts",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE 'den' d. MMMM y",
	"field-thu-relative+-1": "sidste torsdag",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-wide-noon": "middag",
	"dateFormatItem-yMd": "d/M/y",
	"dateFormatItem-yM": "M/y",
	"field-era": "Æra",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"marts",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"september",
		"oktober",
		"november",
		"december"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH.mm.ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "År",
	"dateFormatItem-MMdd": "dd/MM",
	"field-hour": "Time",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mar.",
		"apr.",
		"maj",
		"jun.",
		"jul.",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-sat-relative+0": "denne lørdag",
	"field-sat-relative+1": "næste lørdag",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgen",
	"field-thu-relative+0": "denne torsdag",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"field-thu-relative+1": "næste torsdag",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"quarters-format-abbr": [
		"1. kvt.",
		"2. kvt.",
		"3. kvt.",
		"4. kvt."
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "M",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dayPeriods-format-abbr-noon": "middag",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "denne søndag",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"1. kvt.",
		"2. kvt.",
		"3. kvt.",
		"4. kvt."
	],
	"field-sun-relative+1": "næste søndag",
	"eraAbbr": [
		"f.Kr.",
		"e.Kr."
	],
	"field-minute": "Minut",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"søn",
		"man",
		"tir",
		"ons",
		"tor",
		"fre",
		"lør"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "i går",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'kl.' {0}",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} 'kl.' {0}",
	"field-fri-relative+0": "denne fredag",
	"field-fri-relative+1": "næste fredag",
	"field-day": "Dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "Tidszone",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "sidste år",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"eraNames": [
		"f.Kr.",
		"e.Kr."
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-MMM": "MMM",
	"field-month": "Måned",
	"field-tue-relative+0": "denne tirsdag",
	"field-tue-relative+1": "næste tirsdag",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-relative+0": "denne mandag",
	"field-mon-relative+1": "næste mandag",
	"dateFormat-short": "dd/MM/y",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dayPeriods-format-narrow-noon": "middag",
	"field-second": "Sekund",
	"field-sat-relative+-1": "sidste lørdag",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"field-sun-relative+-1": "sidste søndag",
	"field-month-relative+0": "denne måned",
	"field-month-relative+1": "næste måned",
	"dateFormatItem-Ed": "E 'den' d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Uge",
	"dateFormat-medium": "d. MMM y",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "sidste uge",
	"field-year-relative+1": "næste år",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "sidste mandag",
	"field-week-relative+0": "denne uge",
	"field-week-relative+1": "næste uge"
}
//end v1.x content
);
